@@ -82,6 +82,8 @@ class Generator:
     TYPE_MAPPING = {
         exp.DataType.Type.NCHAR: "CHAR",
         exp.DataType.Type.NVARCHAR: "VARCHAR",
+        exp.DataType.Type.MEDIUMTEXT: "TEXT",
+        exp.DataType.Type.LONGTEXT: "TEXT",
     }
 
     TOKEN_MAPPING: t.Dict[TokenType, str] = {}
@@ -631,10 +633,14 @@ class Generator:
             return self.sep() + self.expressions(properties, indent=False, sep=" ")
         return ""
 
-    def properties(self, properties: exp.Properties, prefix: str = "", sep: str = ", ") -> str:
+    def properties(
+        self, properties: exp.Properties, prefix: str = "", sep: str = ", ", suffix: str = ""
+    ) -> str:
         if properties.expressions:
             expressions = self.expressions(properties, sep=sep, indent=False)
-            return f"{prefix}{' ' if prefix else ''}{self.wrap(expressions)}"
+            return (
+                f"{prefix}{' ' if prefix and prefix != ' ' else ''}{self.wrap(expressions)}{suffix}"
+            )
         return ""
 
     def with_properties(self, properties: exp.Properties) -> str:
@@ -772,14 +778,15 @@ class Generator:
         return self.prepend_ctes(expression, sql)
 
     def values_sql(self, expression: exp.Values) -> str:
-        alias = self.sql(expression, "alias")
         args = self.expressions(expression)
-        if not alias:
-            return f"VALUES{self.seg('')}{args}"
-        alias = f" AS {alias}" if alias else alias
-        if self.WRAP_DERIVED_VALUES:
-            return f"(VALUES{self.seg('')}{args}){alias}"
-        return f"VALUES{self.seg('')}{args}{alias}"
+        alias = self.sql(expression, "alias")
+        values = f"VALUES{self.seg('')}{args}"
+        values = (
+            f"({values})"
+            if self.WRAP_DERIVED_VALUES and (alias or isinstance(expression.parent, exp.From))
+            else values
+        )
+        return f"{values} AS {alias}" if alias else values
 
     def var_sql(self, expression: exp.Var) -> str:
         return self.sql(expression, "this")
@@ -1329,6 +1336,10 @@ class Generator:
 
         return f"ALTER COLUMN {this} DROP DEFAULT"
 
+    def renametable_sql(self, expression: exp.RenameTable) -> str:
+        this = self.sql(expression, "this")
+        return f"RENAME TO {this}"
+
     def altertable_sql(self, expression: exp.AlterTable) -> str:
         actions = expression.args["actions"]
 
@@ -1338,7 +1349,7 @@ class Generator:
             actions = self.expressions(expression, "actions", prefix="ADD COLUMNS ")
         elif isinstance(actions[0], exp.Drop):
             actions = self.expressions(expression, "actions")
-        elif isinstance(actions[0], exp.AlterColumn):
+        elif isinstance(actions[0], (exp.AlterColumn, exp.RenameTable)):
             actions = self.sql(actions[0])
         else:
             self.unsupported(f"Unsupported ALTER TABLE action {actions[0].__class__.__name__}")
